Module

Struct Module 

pub struct Module(/* private fields */);
A TinyWasm WebAssembly Module

This is the internal representation of a WebAssembly module in TinyWasm. Modules produced by the parser are validated by default, but validation can be disabled for trusted input. Do not trust modules or archives from third parties.

Implementations

Source

impl Module

pub fn imports(&self) -> impl Iterator<Item = ModuleImport<'_>>

Returns an iterator over the module’s import descriptors.

The returned data mirrors the module’s import section and preserves order.

pub fn exports(&self) -> impl Iterator<Item = ModuleExport<'_>>

Returns an iterator over the module’s export descriptors.

The returned data mirrors the module’s export section and preserves order.