pub struct Module(/* private fields */);Expand description
A TinyWasm WebAssembly Module
This is the internal representation of a WebAssembly module in TinyWasm.
Module are validated before being created, so they are guaranteed to be valid (as long as they were created by TinyWasm).
This means you should not trust a Module created by a third party to be valid.
Implementations
Sourceimpl Module
impl Module
Sourcepub fn imports(&self) -> impl Iterator<Item = ModuleImport<'_>>
pub fn imports(&self) -> impl Iterator<Item = ModuleImport<'_>>
Returns an iterator over the module’s import descriptors.
The returned data mirrors the module’s import section and preserves order.
Sourcepub fn exports(&self) -> impl Iterator<Item = ModuleExport<'_>>
pub fn exports(&self) -> impl Iterator<Item = ModuleExport<'_>>
Returns an iterator over the module’s export descriptors.
The returned data mirrors the module’s export section and preserves order.